==> tuia-advert-center-api-2.5.35-sources.jar: cn/com/duiba/tuia/core/api/dto/PutLinkageConfigDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * 投放目标联动设置表
 */
public class PutLinkageConfigDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     *
     */
    private Long id;

    /**
     * 新行业标签
     */
    private String newTrade;

    /**
     * 优化目标
     */
    private Integer subType;

    /**
     * 深度优化目标,多个逗号隔开
     */
    private String depthSubTypes;

    /**
     * 深度转化时间
     */
    private Integer depthConverTime;

    /**
     * 转化数要求
     */
    private Integer converSum;

    /**
     * 修改者
     */
    private String tbEditor;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     *  该配置是否开启白名单 0否1是
     * @author fanjia
     * @date 2021/11/12 上午11:00
     * @param null
     * @return null
     */
    private Integer putLinkageConfigWhite;

    public Integer getPutLinkageConfigWhite() {
        return putLinkageConfigWhite;
    }

    public void setPutLinkageConfigWhite(Integer putLinkageConfigWhite) {
        this.putLinkageConfigWhite = putLinkageConfigWhite;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setNewTrade(String newTrade) {
        this.newTrade = newTrade;
    }

    public String getNewTrade() {
        return newTrade;
    }

    public void setSubType(Integer subType) {
        this.subType = subType;
    }

    public Integer getSubType() {
        return subType;
    }

    public void setDepthSubTypes(String depthSubTypes) {
        this.depthSubTypes = depthSubTypes;
    }

    public String getDepthSubTypes() {
        return depthSubTypes;
    }

    public void setDepthConverTime(Integer depthConverTime) {
        this.depthConverTime = depthConverTime;
    }

    public Integer getDepthConverTime() {
        return depthConverTime;
    }

    public void setConverSum(Integer converSum) {
        this.converSum = converSum;
    }

    public Integer getConverSum() {
        return converSum;
    }

    public void setTbEditor(String tbEditor) {
        this.tbEditor = tbEditor;
    }

    public String getTbEditor() {
        return tbEditor;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> tuia-advert-center-api-2.6.27-sources.jar: cn/com/duiba/tuia/core/api/dto/PutLinkageConfigDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * 投放目标联动设置表
 */
public class PutLinkageConfigDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     *
     */
    private Long id;

    /**
     * 新行业标签
     */
    private String newTrade;

    /**
     * 优化目标
     */
    private Integer subType;

    /**
     * 深度优化目标,多个逗号隔开
     */
    private String depthSubTypes;

    /**
     * 深度转化时间
     */
    private Integer depthConverTime;

    /**
     * 转化数要求
     */
    private Integer converSum;

    /**
     * 修改者
     */
    private String tbEditor;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     *  该配置是否开启白名单 0否1是
     * @author fanjia
     * @date 2021/11/12 上午11:00
     * @param null
     * @return null
     */
    private Integer putLinkageConfigWhite;

    /**
     * 二级标签
     */
    private String secondTagNums;

    public Integer getPutLinkageConfigWhite() {
        return putLinkageConfigWhite;
    }

    public void setPutLinkageConfigWhite(Integer putLinkageConfigWhite) {
        this.putLinkageConfigWhite = putLinkageConfigWhite;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setNewTrade(String newTrade) {
        this.newTrade = newTrade;
    }

    public String getNewTrade() {
        return newTrade;
    }

    public void setSubType(Integer subType) {
        this.subType = subType;
    }

    public Integer getSubType() {
        return subType;
    }

    public void setDepthSubTypes(String depthSubTypes) {
        this.depthSubTypes = depthSubTypes;
    }

    public String getDepthSubTypes() {
        return depthSubTypes;
    }

    public void setDepthConverTime(Integer depthConverTime) {
        this.depthConverTime = depthConverTime;
    }

    public Integer getDepthConverTime() {
        return depthConverTime;
    }

    public void setConverSum(Integer converSum) {
        this.converSum = converSum;
    }

    public Integer getConverSum() {
        return converSum;
    }

    public void setTbEditor(String tbEditor) {
        this.tbEditor = tbEditor;
    }

    public String getTbEditor() {
        return tbEditor;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getSecondTagNums() {
        return secondTagNums;
    }

    public void setSecondTagNums(String secondTagNums) {
        this.secondTagNums = secondTagNums;
    }
}
